@@ -4,8 +4,8 @@ import inspect
 class Base:
     INITED = False
 
-    def __init__(self):
-        if self.__class__.INITED:
+    def __init__(self, *, reset_init=False):
+        if self.__class__.INITED and not reset_init:
             raise Exception(f'{self.__class__.__name__} already inited')
 
         self.__class__.INITED = True
